@@ -7,10 +7,10 @@ use warnings;
 # ABSTRACT: Type library for MIDI
 
 #<<<
-our $VERSION = 'v0.0.3'; # TRIAL
+our $VERSION = 'v0.0.4'; # TRIAL
 #>>>
 
-use Type::Library -extends => [ qw(
+use Type::Library 2.000000 -extends => [ qw(
     Types::Common::Numeric
     Types::Common::String
 ) ],
@@ -20,7 +20,7 @@ use Type::Library -extends => [ qw(
     Note
     PercussionNote
     );
-use Type::Utils -all;
+use Type::Utils 2.000000 -all;
 use MIDI;
 use Readonly;
 
@@ -249,7 +249,7 @@ Types::MIDI - Type library for MIDI
 
 =head1 VERSION
 
-version v0.0.3
+version v0.0.4
 
 =head1 SYNOPSIS
 
